;------------------------------------------------------------------------------
;BricsCAD Forum Tools
;------------------------------------------------------------------------------
; This script requires AutoHotkey to run
; https://www.autohotkey.com/

;2019-08-15
;Updated to replace spaces with %20 in search term
;Forum Markdown doesn't like spaces in the search url

;2019-08-21
;Updated to remove minus "-" from  the start of search a term
;Zendesk treats a minus sign as search operator
;Currently a search from BricsCAD removes this from the search term
;Don't know of a way to include an operator in the query

;2019-09-24
;Enhanced the COMMAND help display to use inline block quotes

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#Warn  ; Recommended for catching common errors.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

;------------------------------------------------------------------------------
;INITIALISE GLOBAL VARIABLES
;------------------------------------------------------------------------------

;FORUM SIGNATURE
global ClosingRemark := "Regards"
global Name := "Joe Blogs"

;BricsCAD Version & Type
; Will be omitted if blank ""
global BricsCADVer := "19 Ultimate"

;Company & URL details. Both need to be filled to use.
; Will be omitted if blank ""
global CompanyName := "Joe Inventions"
global CompanyURL := "https://forum.bricsys.com"

;BRICSCAD HELP
;Base URL to BricsCAD online help
global URLbase := "https://help.bricsys.com/hc/en-us/search?query="
;COMMAND Category suffix. Autoload=true automatically loads
global CommandURLsuffix := "&category=360000679494&autoload=true"
;Command tooltip description
global CommandURLDesc :=  "Search the BricsCAD Command Reference for HELP on: "
;General search tooltip description
global SearchURLDesc := "Search the BricsCAD HELP for: "

;OTHER
global SleepTime := 50
global TipDelay := 2000

;----------------
RemoveToolTip:
SetTimer, RemoveToolTip, Off
ToolTip
return

;------------------------------------------------------------------------------
; BRICSCAD FORUM SIGNATURE
;------------------------------------------------------------------------------
; Forum signature in Markup
; 
; Return
::fs::
Sendinput,{Enter}%ClosingRemark%,{Enter}%Name%
if strlen(BricsCADVer)>0
{
	Sendinput,{Enter}BricsCAD V%BricsCADVer%
}
if strlen(CompanyName)>0 and strlen(CompanyURL)>0
{
	sendinput,{Enter}[%CompanyName%](%CompanyURL% "Visit %CompanyName%")
}
ToolTip, Added forum signature
SetTimer, RemoveToolTip, %TipDelay%
return

;------------------------------------------------------------------------------
; BRICSCAD HELP COMMAND REFERENCE
;------------------------------------------------------------------------------
; CTRL + M wraps a help command reference link around the selected text in Markup
; Source: https://autohotkey.com/board/topic/25240-help-in-manipulating-the-selected-text/

^m::
;if WinActive(browser)
;{
  oCB := ClipboardAll ; save old Clipboard
  ;Sendinput, ^c
  ;Use ^c doesn't always work. Breaking this up into steps with a delay is more consistent
  SendInput {LCtrl down}{c down}
	Sleep SleepTime	;
	SendInput {c up}{LCtrl up}
	;Replace all spaces with %20:
	srchTerm := StrReplace(clipboard, A_Space, "%20")
	;Zendesk treats a minus sign as search operator
	;Currently a search from BricsCAD removes this from the search term
	if Instr(srchterm, "-",false,1,1)
		{
			srchTerm := StrReplace(srchTerm, "-",,,1)
		}		
  HelpURL := "[``" clipboard "``]("URLbase srchTerm CommandURLsuffix " """ CommandURLDesc clipboard """" ")"
  clipboard := HelpURL
  ;MsgBox %HelpURL%
  ;SendInput, %HelpURL%
  ;SendInput, ^v
  ;Use ^v also doesn't always work.
  SendInput {LCtrl down}{v down}
	Sleep SleepTime	;
	SendInput {v up}{LCtrl up}
  ClipBoard := oCB ; restore ClipBoard
  oCB := ""	
  ToolTip, Added COMMAND Help Reference
  SetTimer, RemoveToolTip, %TipDelay%
;}
return

;------------------------------------------------------------------------------
; BRICSCAD HELP SEARCH
;------------------------------------------------------------------------------
; CTRL + J wraps a help search link around the selected text in Markup
; Source: https://autohotkey.com/board/topic/25240-help-in-manipulating-the-selected-text/

^J::
;if WinActive(browser)
;{
  oCB := ClipboardAll ; save old Clipboard
  ;Sendinput, ^c
  ;Use a more consistent way to copy to clipboard
  SendInput {LCtrl down}{c down}
	Sleep SleepTime	;
	SendInput {c up}{LCtrl up}
	;Replace all spaces with %20:
	srchTerm := StrReplace(clipboard, A_Space, "%20")
	;Zendesk treats a minus sign as search operator
	;Currently a search from BricsCAD removes this from the search term
	if Instr(srchterm, "-",false,1,1)
		{
			srchTerm := StrReplace(srchTerm, "-",,,1)
		}		
	HelpURL := "[" clipboard "]("URLbase srchTerm " """ SearchURLDesc clipboard """" ")"
  clipboard := HelpURL
  ;MsgBox %HelpURL%
  ;SendInput, %HelpURL%
  ;Use a more consistent way to paste from clipboard
  ;SendInput, ^v
  SendInput {LCtrl down}{v down}
	Sleep SleepTime	;
	SendInput {v up}{LCtrl up}
  ClipBoard := oCB ; restore ClipBoard
  oCB := ""
  ToolTip, Added Help Search
  SetTimer, RemoveToolTip, %TipDelay%
;}
return